#import "SWGScreenshotApi.h"
#import "SWGQueryParamCollection.h"
#import "SWGScreenshot.h"
#import "SWGScreenshotError.h"
#import "SWGScreenshotHost.h"
#import "SWGScreenshotInfoError.h"
#import "SWGScreenshotList.h"
#import "SWGScreenshotShort.h"


@interface SWGScreenshotApi ()

@property (nonatomic, strong) NSMutableDictionary *defaultHeaders;

@end

@implementation SWGScreenshotApi

NSString* kSWGScreenshotApiErrorDomain = @"SWGScreenshotApiErrorDomain";
NSInteger kSWGScreenshotApiMissingParamErrorCode = 234513;

@synthesize apiClient = _apiClient;

#pragma mark - Initialize methods

- (instancetype) init {
    self = [super init];
    if (self) {
        SWGConfiguration *config = [SWGConfiguration sharedConfig];
        if (config.apiClient == nil) {
            config.apiClient = [[SWGApiClient alloc] init];
        }
        _apiClient = config.apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

- (id) initWithApiClient:(SWGApiClient *)apiClient {
    self = [super init];
    if (self) {
        _apiClient = apiClient;
        _defaultHeaders = [NSMutableDictionary dictionary];
    }
    return self;
}

#pragma mark -

+ (instancetype)sharedAPI {
    static SWGScreenshotApi *sharedAPI;
    static dispatch_once_t once;
    dispatch_once(&once, ^{
        sharedAPI = [[self alloc] init];
    });
    return sharedAPI;
}

-(NSString*) defaultHeaderForKey:(NSString*)key {
    return self.defaultHeaders[key];
}

-(void) addHeader:(NSString*)value forKey:(NSString*)key {
    [self setDefaultHeaderValue:value forKey:key];
}

-(void) setDefaultHeaderValue:(NSString*) value forKey:(NSString*)key {
    [self.defaultHeaders setValue:value forKey:key];
}

-(NSUInteger) requestQueueSize {
    return [SWGApiClient requestQueueSize];
}

#pragma mark - Api Methods

///
/// Request a screenshot
/// Screenshots requests to private and shared instances require a positive balance.  *IMPORTANT*: Remember that you can only do 100 free screenshots per month. To used a premium instance, use instance_id=65 for example. 
/// @param url URL of the page to get a screenshot for 
///
/// @param instanceId instance ID to use 
///
/// @param size screenshot size - \"screen\" (default) or \"page\" (optional, default to screen)
///
/// @param cache use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional, default to 86400)
///
/// @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional, default to 5)
///
/// @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional, default to 10)
///
/// @param screenWidth width of the browser window. For desktop browsers only. (optional, default to 1024)
///
/// @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional, default to 768)
///
/// @param priority assign priority to the screenshot (for private instances only) (optional)
///
/// @param referer use a custom referrer header - paid screenshots only (optional)
///
/// @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
///
/// @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
///
/// @param script URL of javascript file to execute after the page load event (optional)
///
/// @param details level of information available with screenshot/info (optional, default to 2)
///
/// @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional, default to 0)
///
/// @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional, default to 0)
///
/// @param headers any custom HTTP headers. (Not supported with Internet Explorer) (optional)
///
/// @param shots take multiple screenshots of the same page. This costs 1 additional credit for every 2 additional screenshots. (optional, default to 1)
///
/// @param shotInterval number of seconds between 2 screenshots (optional, default to 5)
///
/// @param hosting hosting option - s3 or browshot (optional)
///
/// @param hostingHeight maximum height of the thumbnail to host (optional)
///
/// @param hostingWidth maximum height of the thumbnail to host (optional)
///
/// @param hostingScale scale of the thumbnail to host (optional, default to 1)
///
/// @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
///
/// @param hostingFile file name to use (for S3 only) (optional)
///
/// @param hostingHeaders list of headers to add to the S3 object (for S3 only) (optional)
///
///  code:200 message:"Request accepted",
///  code:403 message:"Error"
/// @return SWGScreenshot*
-(NSNumber*) screenshotCreateGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    shots: (NSNumber*) shots
    shotInterval: (NSNumber*) shotInterval
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
    completionHandler: (void (^)(SWGScreenshot* output, NSError* error)) handler {
    // verify the required parameter 'url' is set
    if (url == nil) {
        NSParameterAssert(url);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"url"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'instanceId' is set
    if (instanceId == nil) {
        NSParameterAssert(instanceId);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"instanceId"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/create"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (url != nil) {
        queryParams[@"url"] = url;
    }
    if (instanceId != nil) {
        queryParams[@"instance_id"] = instanceId;
    }
    if (size != nil) {
        queryParams[@"size"] = size;
    }
    if (cache != nil) {
        queryParams[@"cache"] = cache;
    }
    if (delay != nil) {
        queryParams[@"delay"] = delay;
    }
    if (flashDelay != nil) {
        queryParams[@"flash_delay"] = flashDelay;
    }
    if (screenWidth != nil) {
        queryParams[@"screen_width"] = screenWidth;
    }
    if (screenHeight != nil) {
        queryParams[@"screen_height"] = screenHeight;
    }
    if (priority != nil) {
        queryParams[@"priority"] = priority;
    }
    if (referer != nil) {
        queryParams[@"referer"] = referer;
    }
    if (postData != nil) {
        queryParams[@"post_data"] = postData;
    }
    if (cookie != nil) {
        queryParams[@"cookie"] = cookie;
    }
    if (script != nil) {
        queryParams[@"script"] = script;
    }
    if (details != nil) {
        queryParams[@"details"] = details;
    }
    if (html != nil) {
        queryParams[@"html"] = html;
    }
    if (maxWait != nil) {
        queryParams[@"max_wait"] = maxWait;
    }
    if (headers != nil) {
        queryParams[@"headers"] = headers;
    }
    if (shots != nil) {
        queryParams[@"shots"] = shots;
    }
    if (shotInterval != nil) {
        queryParams[@"shot_interval"] = shotInterval;
    }
    if (hosting != nil) {
        queryParams[@"hosting"] = hosting;
    }
    if (hostingHeight != nil) {
        queryParams[@"hosting_height"] = hostingHeight;
    }
    if (hostingWidth != nil) {
        queryParams[@"hosting_width"] = hostingWidth;
    }
    if (hostingScale != nil) {
        queryParams[@"hosting_scale"] = hostingScale;
    }
    if (hostingBucket != nil) {
        queryParams[@"hosting_bucket"] = hostingBucket;
    }
    if (hostingFile != nil) {
        queryParams[@"hosting_file"] = hostingFile;
    }
    if (hostingHeaders != nil) {
        queryParams[@"hosting_headers"] = hostingHeaders;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"SWGScreenshot*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((SWGScreenshot*)data, error);
                                }
                           }
          ];
}

///
/// Delete screenshot data
/// You can delete details of your screenshots to remove any confidential information. 
/// @param _id screenshot ID 
///
/// @param data data to remove. You can specify multiple of them (separated by a ,): *image* (image files), *url* (url requested), *metadata* (time added, time finished, post data, cookie and referer used for the screenshot), *all* (all data and files)  (optional, default to image)
///
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotShort>*
-(NSNumber*) screenshotDeleteGetWithId: (NSNumber*) _id
    data: (NSString*) data
    completionHandler: (void (^)(NSArray<SWGScreenshotShort>* output, NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/delete"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    if (data != nil) {
        queryParams[@"data"] = data;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshotShort>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshotShort>*)data, error);
                                }
                           }
          ];
}

///
/// Host thumbnails on your own S3 account or on Browshot.
/// You can host screenshots and thumbnails on your own S3 account or on Browshot.
/// @param _id screenshot ID 
///
/// @param hosting hosting option: s3 or browshot 
///
/// @param width width of the thumbnail (optional)
///
/// @param height height of the thumbnail (optional)
///
/// @param scale scale of the thumbnail (optional, default to 1)
///
/// @param bucket S3 bucket to upload the screenshot or thumbnail - required with hosting=s3 (optional)
///
/// @param file file name to use - optional, used with hosting=s3 (optional)
///
/// @param headers HTTP headers to add to your S3 object - optional, used with hosting=s3 (optional)
///
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotHost>*
-(NSNumber*) screenshotHostGetWithId: (NSNumber*) _id
    hosting: (NSString*) hosting
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    bucket: (NSString*) bucket
    file: (NSString*) file
    headers: (NSString*) headers
    completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'hosting' is set
    if (hosting == nil) {
        NSParameterAssert(hosting);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"hosting"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/host"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    if (hosting != nil) {
        queryParams[@"hosting"] = hosting;
    }
    if (width != nil) {
        queryParams[@"width"] = width;
    }
    if (height != nil) {
        queryParams[@"height"] = height;
    }
    if (scale != nil) {
        queryParams[@"scale"] = scale;
    }
    if (bucket != nil) {
        queryParams[@"bucket"] = bucket;
    }
    if (file != nil) {
        queryParams[@"file"] = file;
    }
    if (headers != nil) {
        queryParams[@"headers"] = headers;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshotHost>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshotHost>*)data, error);
                                }
                           }
          ];
}

///
/// Get the HTML code
/// Retrieve the HTML code of the rendered page. This API call should be used when html=1 was specified in the screenshot request. 
/// @param _id screenshot ID 
///
///  code:0 message:"HTML code"
-(NSNumber*) screenshotHtmlGetWithId: (NSNumber*) _id
    completionHandler: (void (^)(NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/html"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"text/html"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: nil
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler(error);
                                }
                           }
          ];
}

///
/// Query screenshot status
/// Once a screenshot has been requested, its status must be checked until it is either \"error\" or \"finished\".
/// @param _id screenshot ID received from /api/v1/screenshot/create 
///
/// @param details level of details about the screenshot and the page (optional, default to 2)
///
///  code:200 message:"Screenshot found",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshot>*
-(NSNumber*) screenshotInfoGetWithId: (NSNumber*) _id
    details: (NSNumber*) details
    completionHandler: (void (^)(NSArray<SWGScreenshot>* output, NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/info"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    if (details != nil) {
        queryParams[@"details"] = details;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshot>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshot>*)data, error);
                                }
                           }
          ];
}

///
/// Get information about the last 100 screenshots requested.
/// Get information about the last 100 screenshots requested.
/// @param limit maximum number of screenshots' information to return (optional, default to 100)
///
/// @param status get list of screenshot in a given status (error, finished, in_process) (optional)
///
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotList>*
-(NSNumber*) screenshotListGetWithLimit: (NSNumber*) limit
    status: (NSString*) status
    completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler {
    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/list"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (limit != nil) {
        queryParams[@"limit"] = limit;
    }
    if (status != nil) {
        queryParams[@"status"] = status;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshotList>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshotList>*)data, error);
                                }
                           }
          ];
}

///
/// Request multiple screenshots
/// Request multiple screenshots in one API call. The API call accepts all the parameters supported by screenshot/create. You can specify up to 10 URLs and 10 instances for a total of 100 screenshots in one API call. 
/// @param url URL of the page to get a screenshot for. You can specify multiple url parameters (up to 10). 
///
/// @param instanceId instance ID to use. You can specify multiple instance_id parameters (up to 10). 
///
/// @param size screenshot size - \"screen\" (default) or \"page\" (optional, default to screen)
///
/// @param cache use a previous screenshot (same URL, same instance) if it was done within <cache_value> seconds. The default value is 24hours. Specify cache=0 if you want a new screenshot. (optional, default to 86400)
///
/// @param delay number of seconds to wait after the page has loaded. This is used to let JavaScript run longer before taking the screenshot. Use delay=0 to take screenshots faster. (optional, default to 5)
///
/// @param flashDelay number of seconds to wait after the page has loaded if Flash elements are present. Use flash_delay=0 to take screenshots faster. (optional, default to 10)
///
/// @param screenWidth width of the browser window. For desktop browsers only. (optional, default to 1024)
///
/// @param screenHeight height of the browser window. For desktop browsers only. (Note: full-page screenshots can have a height of up to 15,000px) (optional, default to 768)
///
/// @param priority assign priority to the screenshot (for private instances only) (optional)
///
/// @param referer use a custom referrer header - paid screenshots only (optional)
///
/// @param postData send a POST requests with post_data, useful for filling out forms - paid screenshots only (optional)
///
/// @param cookie set a cookie for the URL requested (see Custom POST Data, Referer and Cookie) Cookies should be separated by a ; - paid screenshots only (optional)
///
/// @param script URL of javascript file to execute after the page load event (optional)
///
/// @param details level of information available with screenshot/info (optional, default to 2)
///
/// @param html saves the HTML of the rendered page which can be retrieved by the API call screenshot/html. This feature costs *1 credit* per screenshot. (optional, default to 0)
///
/// @param maxWait maximum number of seconds to wait before triggering the PageLoad event. Note that delay will still be used. (default: 0 = disabled) (optional, default to 0)
///
/// @param headers any custom HTTP headers. (Not supported with Internet Explorer) (optional)
///
/// @param hosting hosting option - s3 or browshot (optional)
///
/// @param hostingHeight maximum height of the thumbnail to host (optional)
///
/// @param hostingWidth maximum height of the thumbnail to host (optional)
///
/// @param hostingScale scale of the thumbnail to host (optional, default to 1)
///
/// @param hostingBucket S3 bucket to upload the screenshot or thumbnail (required for S3) (optional)
///
/// @param hostingFile file name to use (for S3 only) (optional)
///
/// @param hostingHeaders list of headers to add to the S3 object (for S3 only) (optional)
///
///  code:200 message:"Request accepted",
///  code:403 message:"Error"
/// @return SWGScreenshotList*
-(NSNumber*) screenshotMultipleGetWithUrl: (NSString*) url
    instanceId: (NSNumber*) instanceId
    size: (NSString*) size
    cache: (NSNumber*) cache
    delay: (NSNumber*) delay
    flashDelay: (NSNumber*) flashDelay
    screenWidth: (NSNumber*) screenWidth
    screenHeight: (NSNumber*) screenHeight
    priority: (NSNumber*) priority
    referer: (NSString*) referer
    postData: (NSString*) postData
    cookie: (NSString*) cookie
    script: (NSString*) script
    details: (NSNumber*) details
    html: (NSNumber*) html
    maxWait: (NSNumber*) maxWait
    headers: (NSString*) headers
    hosting: (NSString*) hosting
    hostingHeight: (NSNumber*) hostingHeight
    hostingWidth: (NSNumber*) hostingWidth
    hostingScale: (NSNumber*) hostingScale
    hostingBucket: (NSString*) hostingBucket
    hostingFile: (NSString*) hostingFile
    hostingHeaders: (NSString*) hostingHeaders
    completionHandler: (void (^)(SWGScreenshotList* output, NSError* error)) handler {
    // verify the required parameter 'url' is set
    if (url == nil) {
        NSParameterAssert(url);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"url"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    // verify the required parameter 'instanceId' is set
    if (instanceId == nil) {
        NSParameterAssert(instanceId);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"instanceId"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/multiple"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (url != nil) {
        queryParams[@"url"] = url;
    }
    if (instanceId != nil) {
        queryParams[@"instance_id"] = instanceId;
    }
    if (size != nil) {
        queryParams[@"size"] = size;
    }
    if (cache != nil) {
        queryParams[@"cache"] = cache;
    }
    if (delay != nil) {
        queryParams[@"delay"] = delay;
    }
    if (flashDelay != nil) {
        queryParams[@"flash_delay"] = flashDelay;
    }
    if (screenWidth != nil) {
        queryParams[@"screen_width"] = screenWidth;
    }
    if (screenHeight != nil) {
        queryParams[@"screen_height"] = screenHeight;
    }
    if (priority != nil) {
        queryParams[@"priority"] = priority;
    }
    if (referer != nil) {
        queryParams[@"referer"] = referer;
    }
    if (postData != nil) {
        queryParams[@"post_data"] = postData;
    }
    if (cookie != nil) {
        queryParams[@"cookie"] = cookie;
    }
    if (script != nil) {
        queryParams[@"script"] = script;
    }
    if (details != nil) {
        queryParams[@"details"] = details;
    }
    if (html != nil) {
        queryParams[@"html"] = html;
    }
    if (maxWait != nil) {
        queryParams[@"max_wait"] = maxWait;
    }
    if (headers != nil) {
        queryParams[@"headers"] = headers;
    }
    if (hosting != nil) {
        queryParams[@"hosting"] = hosting;
    }
    if (hostingHeight != nil) {
        queryParams[@"hosting_height"] = hostingHeight;
    }
    if (hostingWidth != nil) {
        queryParams[@"hosting_width"] = hostingWidth;
    }
    if (hostingScale != nil) {
        queryParams[@"hosting_scale"] = hostingScale;
    }
    if (hostingBucket != nil) {
        queryParams[@"hosting_bucket"] = hostingBucket;
    }
    if (hostingFile != nil) {
        queryParams[@"hosting_file"] = hostingFile;
    }
    if (hostingHeaders != nil) {
        queryParams[@"hosting_headers"] = hostingHeaders;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"SWGScreenshotList*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((SWGScreenshotList*)data, error);
                                }
                           }
          ];
}

///
/// Search for screenshots of a specific URL.
/// Search for screenshots of a specific URL.
/// @param url look for a string matching the URL requested 
///
/// @param limit maximum number of screenshots' information to return (optional, default to 50)
///
/// @param status get list of screenshot in a given status (error, finished, in_process) (optional)
///
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotList>*
-(NSNumber*) screenshotSearchGetWithUrl: (NSString*) url
    limit: (NSNumber*) limit
    status: (NSString*) status
    completionHandler: (void (^)(NSArray<SWGScreenshotList>* output, NSError* error)) handler {
    // verify the required parameter 'url' is set
    if (url == nil) {
        NSParameterAssert(url);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"url"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/search"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (url != nil) {
        queryParams[@"url"] = url;
    }
    if (limit != nil) {
        queryParams[@"limit"] = limit;
    }
    if (status != nil) {
        queryParams[@"status"] = status;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshotList>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshotList>*)data, error);
                                }
                           }
          ];
}

///
/// Share a screenshot
/// You can make your screenshots public, add notes, and share it with your friends and colleagues. Only screenshots which are successfully completed can be shared.n the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
/// @param _id screenshot ID 
///
/// @param note note to add on the sharing page (optional)
///
///  code:200 message:"list of screenshot information",
///  code:0 message:"Screenshot not found"
/// @return NSArray<SWGScreenshotHost>*
-(NSNumber*) screenshotShareGetWithId: (NSNumber*) _id
    note: (NSString*) note
    completionHandler: (void (^)(NSArray<SWGScreenshotHost>* output, NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(nil, error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/share"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    if (note != nil) {
        queryParams[@"note"] = note;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"application/json"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: @"NSArray<SWGScreenshotHost>*"
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler((NSArray<SWGScreenshotHost>*)data, error);
                                }
                           }
          ];
}

///
/// Retrieve a thumbnail image
/// Unlike the other API calls, this API sends back the thumbnail as a PNG file, not JSON. The HTTP response code indicates whether the screenshot was successful (200), or incomplete (404) or failed (404). If the screenshot failed or is not finished, a default image \"Not found\" is sent.  You can crop your screenshots. The crop is done first, then the thumbnail. You can take a 1024x768 screenshot, crop it to 768x768, and get it scaled down to 300x300. 
/// @param _id screenshot ID 
///
/// @param width width of the thumbnail (optional)
///
/// @param height height of the thumbnail (optional)
///
/// @param scale scale of the thumbnail (optional, default to 1)
///
/// @param zoom zoom 1 to 100 percent (optional, default to 100)
///
/// @param ratio Use fit to keep the original page ration, and fill to get a thumbnail for the exact width and height.  specified. If you provide both width and height, you need to specify the ratio: fit to keep the original width/height ratio (the thumbnail might be smaller than the specified width and height), or fill to crop the image if necessary. (optional, default to fit)
///
/// @param left left edge of the area to be cropped (optional, default to 0)
///
/// @param right right edge of the area to be cropped (optional, default to 0)
///
/// @param top top edge of the area to be cropped (optional, default to 0)
///
/// @param bottom bottom edge of the area to be cropped (optional)
///
/// @param format image as PNG or JPEG (optional, default to png)
///
/// @param shot get the second or third screenshot if multiple screenshots were requested (optional, default to 1)
///
/// @param quality JPEG quality factor (for JPEG thumbnails only) (optional, default to 100)
///
///  code:200 message:"thumbnail",
///  code:404 message:"Screenshot not found"
-(NSNumber*) screenshotThumbnailGetWithId: (NSNumber*) _id
    width: (NSNumber*) width
    height: (NSNumber*) height
    scale: (NSNumber*) scale
    zoom: (NSNumber*) zoom
    ratio: (NSString*) ratio
    left: (NSNumber*) left
    right: (NSNumber*) right
    top: (NSNumber*) top
    bottom: (NSNumber*) bottom
    format: (NSString*) format
    shot: (NSNumber*) shot
    quality: (NSNumber*) quality
    completionHandler: (void (^)(NSError* error)) handler {
    // verify the required parameter '_id' is set
    if (_id == nil) {
        NSParameterAssert(_id);
        if(handler) {
            NSDictionary * userInfo = @{NSLocalizedDescriptionKey : [NSString stringWithFormat:NSLocalizedString(@"Missing required parameter '%@'", nil),@"_id"] };
            NSError* error = [NSError errorWithDomain:kSWGScreenshotApiErrorDomain code:kSWGScreenshotApiMissingParamErrorCode userInfo:userInfo];
            handler(error);
        }
        return nil;
    }

    NSMutableString* resourcePath = [NSMutableString stringWithFormat:@"/screenshot/thumbnail"];

    // remove format in URL if needed
    [resourcePath replaceOccurrencesOfString:@".{format}" withString:@".json" options:0 range:NSMakeRange(0,resourcePath.length)];

    NSMutableDictionary *pathParams = [[NSMutableDictionary alloc] init];

    NSMutableDictionary* queryParams = [[NSMutableDictionary alloc] init];
    if (_id != nil) {
        queryParams[@"id"] = _id;
    }
    if (width != nil) {
        queryParams[@"width"] = width;
    }
    if (height != nil) {
        queryParams[@"height"] = height;
    }
    if (scale != nil) {
        queryParams[@"scale"] = scale;
    }
    if (zoom != nil) {
        queryParams[@"zoom"] = zoom;
    }
    if (ratio != nil) {
        queryParams[@"ratio"] = ratio;
    }
    if (left != nil) {
        queryParams[@"left"] = left;
    }
    if (right != nil) {
        queryParams[@"right"] = right;
    }
    if (top != nil) {
        queryParams[@"top"] = top;
    }
    if (bottom != nil) {
        queryParams[@"bottom"] = bottom;
    }
    if (format != nil) {
        queryParams[@"format"] = format;
    }
    if (shot != nil) {
        queryParams[@"shot"] = shot;
    }
    if (quality != nil) {
        queryParams[@"quality"] = quality;
    }
    NSMutableDictionary* headerParams = [NSMutableDictionary dictionaryWithDictionary:self.apiClient.configuration.defaultHeaders];
    [headerParams addEntriesFromDictionary:self.defaultHeaders];
    // HTTP header `Accept`
    NSString *acceptHeader = [self.apiClient.sanitizer selectHeaderAccept:@[@"image/png", @"image/jpeg"]];
    if(acceptHeader.length > 0) {
        headerParams[@"Accept"] = acceptHeader;
    }

    // response content type
    NSString *responseContentType = [[acceptHeader componentsSeparatedByString:@", "] firstObject] ?: @"";

    // request content type
    NSString *requestContentType = [self.apiClient.sanitizer selectHeaderContentType:@[]];

    // Authentication setting
    NSArray *authSettings = @[@"apiKeyQuery"];

    id bodyParam = nil;
    NSMutableDictionary *formParams = [[NSMutableDictionary alloc] init];
    NSMutableDictionary *localVarFiles = [[NSMutableDictionary alloc] init];

    return [self.apiClient requestWithPath: resourcePath
                                    method: @"GET"
                                pathParams: pathParams
                               queryParams: queryParams
                                formParams: formParams
                                     files: localVarFiles
                                      body: bodyParam
                              headerParams: headerParams
                              authSettings: authSettings
                        requestContentType: requestContentType
                       responseContentType: responseContentType
                              responseType: nil
                           completionBlock: ^(id data, NSError *error) {
                                if(handler) {
                                    handler(error);
                                }
                           }
          ];
}


@end
